ScriptException class

An exception indicating that a Script failed.

Implemented types

Constructors

ScriptException(String scriptName, int exitCode)

Properties

exitCode → int
The exit code produced by the failing script.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptName → String
The human-readable name of the script that failed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited